@@ -66,6 +66,7 @@ type MetaArgs struct {
 	// TODO(azr): in the future, I want to allow passing multiple path to
 	// merge HCL confs together; but this will probably need an RFC first.
 	Path         string
+	Paths        []string
 	Only, Except []string
 	Vars         map[string]string
 	VarFiles     []string
@@ -156,6 +157,10 @@ type PluginsRequiredArgs struct {
 	MetaArgs
 }
 
+func (ca *ConsoleArgs) AddFlagSets(flags *flag.FlagSet) {
+	flags.BoolVar(&ca.MetaArgs.UseSequential, "use-sequential-evaluation", false, "Fallback to using a sequential approach for local/datasource evaluation.")
+}
+
 // ConsoleArgs represents a parsed cli line for a `packer console`
 type ConsoleArgs struct {
 	MetaArgs
@@ -163,7 +168,6 @@ type ConsoleArgs struct {
 
 func (fa *FixArgs) AddFlagSets(flags *flag.FlagSet) {
 	flags.BoolVar(&fa.Validate, "validate", true, "")
-	flags.BoolVar(&fa.MetaArgs.UseSequential, "use-sequential-evaluation", false, "Fallback to using a sequential approach for local/datasource evaluation.")
 
 	fa.MetaArgs.AddFlagSets(flags)
 }
