@@ -11,6 +11,8 @@ import (
 	"runtime"
 	"strings"
 
+	"github.com/hashicorp/packer/packer/plugin-getter/release"
+
 	gversion "github.com/hashicorp/go-version"
 	pluginsdk "github.com/hashicorp/packer-plugin-sdk/plugin"
 	"github.com/hashicorp/packer/packer"
@@ -76,7 +78,7 @@ for more info.`)
 	}
 
 	opts := plugingetter.ListInstallationsOptions{
-		FromFolders: c.Meta.CoreConfig.Components.PluginConfig.KnownPluginFolders,
+		PluginDirectory: c.Meta.CoreConfig.Components.PluginConfig.PluginDirectory,
 		BinaryInstallationOptions: plugingetter.BinaryInstallationOptions{
 			OS:              runtime.GOOS,
 			ARCH:            runtime.GOARCH,
@@ -85,6 +87,7 @@ for more info.`)
 			Checksummers: []plugingetter.Checksummer{
 				{Type: "sha256", Hash: sha256.New()},
 			},
+			ReleasesOnly: true,
 		},
 	}
 
@@ -94,7 +97,11 @@ for more info.`)
 
 	log.Printf("[TRACE] init: %#v", opts)
 
+	// the ordering of the getters is important here, place the getter on top which you want to try first
 	getters := []plugingetter.Getter{
+		&release.Getter{
+			Name: "releases.hashicorp.com",
+		},
 		&github.Getter{
 			// In the past some terraform plugins downloads were blocked from a
 			// specific aws region by s3. Changing the user agent unblocked the
@@ -104,6 +111,7 @@ for more info.`)
 			// TODO: allow to set this from the config file or an environment
 			// variable.
 			UserAgent: "packer-getter-github-" + version.String(),
+			Name:      "github.com",
 		},
 	}
 
@@ -127,12 +135,25 @@ for more info.`)
 			}
 
 			if cla.Force && !cla.Upgrade {
-				pluginRequirement.VersionConstraints, _ = gversion.NewConstraint(fmt.Sprintf("=%s", installs[len(installs)-1].Version))
+				// Only place another constaint to the latest release
+				// binary, if any, otherwise this is essentially the same
+				// as an upgrade
+				var installVersion string
+				for _, install := range installs {
+					ver, _ := gversion.NewVersion(install.Version)
+					if ver.Prerelease() == "" {
+						installVersion = install.Version
+					}
+				}
+
+				if installVersion != "" {
+					pluginRequirement.VersionConstraints, _ = gversion.NewConstraint(fmt.Sprintf("=%s", installVersion))
+				}
 			}
 		}
 
 		newInstall, err := pluginRequirement.InstallLatest(plugingetter.InstallOptions{
-			InFolders:                 opts.FromFolders,
+			PluginDirectory:           opts.PluginDirectory,
 			BinaryInstallationOptions: opts.BinaryInstallationOptions,
 			Getters:                   getters,
 			Force:                     cla.Force,
