@@ -1,3 +1,6 @@
+// Copyright (c) HashiCorp, Inc.
+// SPDX-License-Identifier: BUSL-1.1
+
 package fix
 
 import (
@@ -8,6 +11,12 @@ import (
 // with the newer "iso_checksum" and "iso_checksum_type" within builders.
 type FixerISOMD5 struct{}
 
+func (FixerISOMD5) DeprecatedOptions() map[string][]string {
+	return map[string][]string{
+		"*": []string{"iso_md5"},
+	}
+}
+
 func (FixerISOMD5) Fix(input map[string]interface{}) (map[string]interface{}, error) {
 	// Our template type we'll use for this fixer only
 	type template struct {
