@@ -55,8 +55,9 @@ func (cfg *PackerConfig) PluginRequirements() (plugingetter.Requirements, hcl.Di
 }
 
 func (cfg *PackerConfig) DetectPluginBinaries() hcl.Diagnostics {
+	// Then we can apply any constraint from the template, if any
 	opts := plugingetter.ListInstallationsOptions{
-		FromFolders: cfg.parser.PluginConfig.KnownPluginFolders,
+		PluginDirectory: cfg.parser.PluginConfig.PluginDirectory,
 		BinaryInstallationOptions: plugingetter.BinaryInstallationOptions{
 			OS:              runtime.GOOS,
 			ARCH:            runtime.GOARCH,
@@ -65,6 +66,7 @@ func (cfg *PackerConfig) DetectPluginBinaries() hcl.Diagnostics {
 			Checksummers: []plugingetter.Checksummer{
 				{Type: "sha256", Hash: sha256.New()},
 			},
+			ReleasesOnly: cfg.parser.PluginConfig.ReleasesOnly,
 		},
 	}
 
@@ -120,6 +122,16 @@ func (cfg *PackerConfig) DetectPluginBinaries() hcl.Diagnostics {
 		})
 	}
 
+	// Do a second pass to discover the remaining installed plugins
+	err := cfg.parser.PluginConfig.Discover()
+	if err != nil {
+		return (hcl.Diagnostics{}).Append(&hcl.Diagnostic{
+			Severity: hcl.DiagError,
+			Summary:  "Failed to discover installed plugins",
+			Detail:   err.Error(),
+		})
+	}
+
 	return diags
 }
 
