@@ -74,11 +74,19 @@ func (bucket *Bucket) Validate() error {
 
 // ReadFromHCLBuildBlock reads the information for initialising a Bucket from a HCL2 build block
 func (bucket *Bucket) ReadFromHCLBuildBlock(build *hcl2template.BuildBlock) {
+	registryBlock := build.HCPPackerRegistry
+	if registryBlock == nil {
+		return
+	}
+	bucket.ReadFromHCPPackerRegistryBlock(build.HCPPackerRegistry)
+}
+
+// ReadFromHCPPackerRegistryBlock reads the information for initialising a Bucket from a HCL2 Packer registry block
+func (bucket *Bucket) ReadFromHCPPackerRegistryBlock(registryBlock *hcl2template.HCPPackerRegistryBlock) {
 	if bucket == nil {
 		return
 	}
 
-	registryBlock := build.HCPPackerRegistry
 	if registryBlock == nil {
 		return
 	}
