@@ -62,7 +62,7 @@ func (p *UiProgressBar) TrackProgress(src string, currentSize, totalSize int64,
 			newPb.Finish()
 			p.pbs--
 			if p.pbs <= 0 {
-				p.pool.Stop()
+				_ = p.pool.Stop()
 				p.pool = nil
 			}
 			return nil
