@@ -66,6 +66,11 @@ type Config struct {
 	// name of the tmp environment variable file, if UseEnvVarFile is true
 	envVarFile string
 
+	// Set true if user provided a shebang for inline scripts.
+	// This is used to determine if the default shebang must be used
+	// or should be taken from inline commands
+	inlineShebangDefined bool
+
 	ctx interpolate.Context
 }
 
@@ -113,6 +118,8 @@ func (p *Provisioner) Prepare(raws ...interface{}) error {
 
 	if p.config.InlineShebang == "" {
 		p.config.InlineShebang = "/bin/sh -e"
+	} else {
+		p.config.inlineShebangDefined = true
 	}
 
 	if p.config.StartRetryTimeout == 0 {
@@ -201,21 +208,30 @@ func (p *Provisioner) Provision(ctx context.Context, ui packersdk.Ui, comm packe
 		// Set the path to the temporary file
 		scripts = append(scripts, tf.Name())
 
-		// Write our contents to it
-		writer := bufio.NewWriter(tf)
-		_, _ = writer.WriteString(fmt.Sprintf("#!%s\n", p.config.InlineShebang))
+		// Write all inline commands to this buffer
+		commandBuffer := strings.Builder{}
 		for _, command := range p.config.Inline {
 			p.config.ctx.Data = generatedData
 			command, err := interpolate.Render(command, &p.config.ctx)
 			if err != nil {
 				return fmt.Errorf("Error interpolating Inline: %s", err)
 			}
-			if _, err := writer.WriteString(command + "\n"); err != nil {
+			if _, err := fmt.Fprintf(&commandBuffer, "%s\n", command); err != nil {
 				return fmt.Errorf("Error preparing shell script: %s", err)
 			}
 		}
 
-		if err := writer.Flush(); err != nil {
+		// If the user has defined an inline shebang, use that.
+		// Or If command does not start with a shebang, use the default shebang.
+		// else command already has a shebang, so do not write it.
+		if p.config.inlineShebangDefined || !strings.HasPrefix(commandBuffer.String(), "#!") {
+			if _, err := fmt.Fprintf(tf, "#!%s\n", p.config.InlineShebang); err != nil {
+				return fmt.Errorf("Error preparing shell script: %s", err)
+			}
+		}
+
+		// Write the collected commands to the file
+		if _, err := tf.WriteString(commandBuffer.String()); err != nil {
 			return fmt.Errorf("Error preparing shell script: %s", err)
 		}
 
